@@ -1,5 +1,5 @@
 from contextlib import contextmanager
-from typing import Any, Callable, Dict
+from typing import Any, Dict, Iterator
 
 import requests
 from requests.utils import default_headers
@@ -7,6 +7,7 @@ from requests.utils import default_headers
 import laituri
 from laituri.docker.credential_manager.docker_v1 import docker_v1_credential_manager
 from laituri.docker.credential_manager.errors import CallbackFailed
+from laituri.types import LogStatusCallable, RegistryCredentialsDict
 from laituri.utils.retry import retry
 
 
@@ -14,9 +15,9 @@ from laituri.utils.retry import retry
 def registry_credentials_callback_v1_credential_manager(
     *,
     image: str,
-    registry_credentials: Dict,
-    log_status: Callable
-):
+    registry_credentials: RegistryCredentialsDict,
+    log_status: LogStatusCallable,
+) -> Iterator[None]:
     try:
         docker_credentials = fetch_docker_credentials(registry_credentials)
     except Exception as exc:
@@ -26,9 +27,9 @@ def registry_credentials_callback_v1_credential_manager(
         yield
 
 
-@retry()
-def fetch_docker_credentials(request_info: Dict[str, Any]) -> Dict:
-    headers = default_headers()
+@retry(tries=10)
+def fetch_docker_credentials(request_info: Dict[str, Any]) -> RegistryCredentialsDict:
+    headers = default_headers()  # type: ignore[no-untyped-call]
     headers['User-Agent'] = f'{headers.get("User-Agent")} laituri/{laituri.__version__}'
     ri_headers = request_info.get('headers')
     if isinstance(ri_headers, dict):
@@ -41,4 +42,7 @@ def fetch_docker_credentials(request_info: Dict[str, Any]) -> Dict:
         timeout=15,
     )
     response.raise_for_status()
-    return response.json()
+    data = response.json()
+    if not isinstance(data, dict):
+        raise ValueError(f"Invalid response data: {data}")
+    return {str(k): v for (k, v) in data.items()}
